﻿$(function () {
    setupFromClientStorage();
    setupAjaxEvents();
    setupClientFileAccessEvents();
    setupOtherClientEvents();
    fireInitEvents();

    function setupFromClientStorage() {
        if (clientStorage.hasValue()) {
            $("#LocalStoreWarning").data("allow", true);
            getValueToField("ProtocolFolder");
            getValueToField("ParkedXmlFolder");
            getValueToField("GpXmlFolder");
            getValueToField("PmsXmlFolder");
            getValueToField("PreviewStylesheetFolder");
        }
        else {
            $("#LocalStoreWarning").data("allow", false).show();
            $("#LocalStoreY").click(function () {
                $("#LocalStoreWarning").hide().data("allow", true);
            });
            $("#LocalStoreN").click(function () {
                clientStorage.clear(); $("#LocalStoreWarning").hide().data("allow", false);
            });
        }

        function getValueToField(fieldId) {
            var value = clientStorage.getValue(fieldId);
            if (value != null) {
                $("#" + fieldId).val(value);
            }
        }
    }

    function setupAjaxEvents() {
        $("#ProtocolTypes").change(function () { defaultAjax.PopulateProtocolSchemaVersions(); });
        $("#MessageTypes").change(function () { defaultAjax.PopulateFinalMessageSchemas(); });
        $("#PrePopulationMethods").change(function () { defaultUI.showHidePrePopulationMethods(); });
        $("#ValidateButton").click(function () { defaultUI.validateSelectedProtocols(); });
    }

    function setupClientFileAccessEvents() {
        $("#ProtocolFolder, #ProtocolFilesRefresh")
            .data("controls", { files: $("#ProtocolFiles"), folder: $("#ProtocolFolder")[0], selectText: "(All)", fileTypes: "xml" });
        $("#ParkedXmlFolder, #ParkedXmlFilesRefresh")
            .data("controls", { files: $("#ParkedXmlFiles"), folder: $("#ParkedXmlFolder")[0], fileTypes: "xml" });
        $("#GpXmlFolder, #GpXmlFilesRefresh")
            .data("controls", { files: $("#GpXmlFiles"), folder: $("#GpXmlFolder")[0], fileTypes: "xml" });
        $("#PmsXmlFolder, #PmsXmlFilesRefresh")
            .data("controls", { files: $("#PmsXmlFiles"), folder: $("#PmsXmlFolder")[0], fileTypes: "xml" });
        $("#PreviewStylesheetFolder, #PreviewStylesheetFilesRefresh")
            .data("controls", { files: $("#PreviewStylesheetFiles"), folder: $("#PreviewStylesheetFolder")[0], fileTypes: "xml;xsl;xslt" });

        $("fieldset input[type='text'].folderInput").change(function () {
            if ($("#LocalStoreWarning").data("allow")) {
                var data = $(this).data("controls");
                clientStorage.setValue(data.folder.id, data.folder.value);
            }
            PopulateFileNames($(this));
        });
        $("fieldset input[type='button'].refreshFiles").click(function () {
            if ($("#LocalStoreWarning").data("allow")) {
                var data = $(this).data("controls");
                clientStorage.setValue(data.folder.id, data.folder.value);
            }
            PopulateFileNames($(this));
        });

        SetupDialogBrowserButton($("#ProtocolFolderBrowser"), $("#ProtocolFolder"));
        SetupDialogBrowserButton($("#ParkedXmlFolderBrowser"), $("#ParkedXmlFolder"));
        SetupDialogBrowserButton($("#GpXmlFolderBrowser"), $("#GpXmlFolder"));
        SetupDialogBrowserButton($("#PmsXmlFolderBrowser"), $("#PmsXmlFolder"));
        SetupDialogBrowserButton($("#PreviewStylesheetFolderBrowser"), $("#PreviewStylesheetFolder"));
    }

    function setupOtherClientEvents() {
        $("#CloseResults").click(function () {
            $("#validationResultContainer").hide();
        });
    }

    function SetupDialogBrowserButton(jqueryBrowserOpenButton, jqueryFolderInput) {
        jqueryBrowserOpenButton.click(function () {
            var newValue = clientFsa.requestFolderDialog(jqueryFolderInput.val());
            if (newValue !== jqueryFolderInput.val()) {
                jqueryFolderInput.val(newValue);
                jqueryFolderInput.change();
            }
        });
    }

    function PopulateFileNames(jQueryObj) {
        var data = jQueryObj.data('controls');
        defaultUI.showHideLoadingIndicator(data.files, true);

        // File system access may cause UI to not update, so give time to allow loading indicator to show (albeit un-animated)
        setTimeout(function () {
            var files = clientFsa.getFileNamesInPath(data.folder.value, data.fileTypes);
            var valueTextPairs = new Array();
            if (files[0].indexOf("(") !== 0) {
                valueTextPairs.push({ text: data.selectText === undefined ? "(Select file)" : data.selectText });
            }

            for (var i = 0; i < files.length; i++) {
                valueTextPairs.push({
                    value:
                        files[0].indexOf("(") !== 0
                        ? files[i]
                        : undefined,
                    text:
                        data.folder.value.lastIndexOf("\\") === data.folder.value.length - 1
                        ? files[i].replace(data.folder.value, "")
                        : files[i].replace(data.folder.value + "\\", "")
                });
            }

            defaultUI.populateDropDownWithOptionsAndAttributes(data.files, valueTextPairs);
        }, 2);
    }

    function fireInitEvents() {
        defaultAjax.PopulateProtocolTypes();
        defaultAjax.PopulateMessageTypes();
        defaultAjax.PopulatePrePopulationMethods();
        $("fieldset input[type='button'].refreshFiles").click();
    }
});

function defaultUI() {
}

defaultUI.populateDropDownWithOptionsAndAttributes = function (controls, selectValues) {
    controls.empty();
    if (selectValues !== null) {
        $.each(selectValues, function () {
            controls.append($('<option>', this));
            $(this).css("width", "");
        });
    }

    defaultUI.showHideLoadingIndicator(controls, false);
}

defaultUI.showHideLoadingIndicator = function (jQueryObj, show) {
    if (show) {
        jQueryObj.siblings("label").addClass("loading");
    } else {
        jQueryObj.siblings("label").removeClass("loading");
    }
}

defaultUI.showHidePrePopulationMethods = function() {
    switch ($('#PrePopulationMethods').val()) {
        case "No pre-population":
            $("#ParkedXmlFields, #GpXmlFields, #PmsXmlFields").hide();
            break;
        case "Parked XML":
            $("#GpXmlFields, #PmsXmlFields").hide();
            $("#ParkedXmlFields").show();
            break;
        case "GP XML":
            $("#ParkedXmlFields, #PmsXmlFields").hide();
            $("#GpXmlFields").show();
            break;
        case "PMS XML":
            $("#ParkedXmlFields, #GpXmlFields").hide();
            $("#PmsXmlFields").show();
            break;
        default:
            alert("Unknown pre-population method!");
            break;
    }
}

defaultUI.validateSelectedProtocols = function () {
    $("#validationResultDetailsContainer > div.resultContainer").remove();
    $("#validationResultContainer").show();
    var protocolFilesValue = $("#ProtocolFiles").val();
    var filesToValidate = new Array();
    if (protocolFilesValue === "(All)") {
        $("#ProtocolFiles > option").each(function () {
            var me = $(this);
            if (me.val() !== "(All)") {
                filesToValidate.push(me.val());
            }
        });
    } else {
        filesToValidate.push(protocolFilesValue);
    }

    var protocolType = $("#ProtocolTypes").val();
    var protocolTypeSchema = $("#ProtocolSchemaVersions").val();
    var messageTypesValue = $("#MessageTypes").val();
    var finalMessageSchemasValue = $("#FinalMessageSchemas").val();

    // process in batches to prevent server overload if thousands of protocols to validate
    var batch = filesToValidate.splice(0, 5);
    for (var i = 0; i < batch.length; i++) {
        defaultAjax.validateProtocol(batch[i], protocolType, protocolTypeSchema, messageTypesValue, finalMessageSchemasValue, itemCompleteCallback);
    }

    // process the next protocol off the list
    function itemCompleteCallback() {
        if (filesToValidate.length > 0) {
            var fileToValidate = filesToValidate.shift();
            defaultAjax.validateProtocol(fileToValidate, protocolType, protocolTypeSchema, messageTypesValue, finalMessageSchemasValue, itemCompleteCallback)
        }
    }
}

defaultUI.openViewProtocolForm = function (protocolXml, outputWindow) {
    if (outputWindow === undefined || outputWindow == null) {
        outputWindow = window.open("ViewProtocolForm.aspx", "_blank", "width=786,height=700,resizable=yes,scrollbars=yes");
    }

    if (outputWindow === undefined || outputWindow == null || outputWindow.document == null || outputWindow.document.forms == null || outputWindow.document.forms["formRef"] == null) {
        window.setTimeout(function () { defaultUI.openViewProtocolForm(protocolXml, outputWindow); }, 50);
    } else {
        var postForm = outputWindow.document.forms["formRef"];
        postForm.PostedProtocolXml.value = encodeURIComponent(clientFsa.ReadAllFile(protocolXml));
        postForm.PostedProtocolType.value = $("#ProtocolTypes")[0].value == "" ? "" : $("#ProtocolTypes")[0].value;
        postForm.PostedProtocolSchemaVersion.value = $("#ProtocolSchemaVersions")[0].value == "" ? "" : $("#ProtocolSchemaVersions")[0].value;
        postForm.PostedMessageTypeName.value = $("#MessageTypes")[0].value == "" ? "" : $("#MessageTypes").val();
        postForm.PostedMessageSchemaVersion.value = $("#FinalMessageSchemas")[0].value == "" ? "" : $("#FinalMessageSchemas")[0].value;
        postForm.PostedPrePopMethod.value = $("#PrePopulationMethods")[0].value == "" ? "" : $("#PrePopulationMethods")[0].value;

        // Didn't want to use the name value in #PrePopulationMethods in case they change server side (where they are stored)
        var visibleEntry = $("#ParkedXmlFields, #GpXmlFields, #PmsXmlFields").find(":not(:hidden)");
        postForm.PostedPrePopXml.value = visibleEntry.length == 0 || visibleEntry.find("select")[0].value == "" ? "" : encodeURIComponent(clientFsa.ReadAllFile(visibleEntry.find("select")[0].value));
        postForm.PostedPreviewStylesheetXslt.value = $("#PreviewStylesheetFiles")[0].value == "" ? "" : encodeURIComponent(clientFsa.ReadAllFile($("#PreviewStylesheetFiles")[0].value));
        postForm.submit();
    }
}