<?xml version="1.0" encoding="UTF-8"?>
<!--This stylesheet takes patient detail xml (tpi:) and converts it into prepopulation source xml (pps:) -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tpi="http://www.show.scot.nhs.uk/isd/ThirdPartyInterface" xmlns:pps="http://www.show.scot.nhs.uk/isd/PrePopulationSource"  xmlns:fn="http://www.w3.org/2005/xpath-functions">
	<xsl:output method="xml" encoding="UTF-8" indent="yes"/>
	<!-- Map a PATIENT_TYPE (tpi: v1.7) to PREPOPULATION_TYPE (pps: v1.4) -->
	<xsl:template match="tpi:PatientDetailsDocument">
		<xsl:element name="PrePopulationDocument" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:apply-templates select="node()|@*"/>
		</xsl:element>
	</xsl:template>
	<!-- change the root node schema version -->
	<xsl:template match="tpi:PatientDetailsDocument/@SchemaVersion">
		<xsl:attribute name="SchemaVersion"><xsl:value-of select="1.4"/></xsl:attribute>
	</xsl:template>
	<!-- Change the tpi namespaces to the pps namespace -->
	<xsl:template match="tpi:*">
		<xsl:element name="{local-name()}" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:apply-templates select="node()|@*"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="node()|@*">
		<xsl:if test="./ancestor-or-self::tpi:PatientDetailsDocument">	<!-- to ensure we only copy correct namespace elements-->
			<xsl:copy>
				<xsl:apply-templates select="node()|@*"/>
			</xsl:copy>
		</xsl:if>
	</xsl:template>
	<!-- Sort by date and time and map BLOOD_PRESSURES_TYPE (tpi: v1.7) to BLOOD_PRESSURES_TYPE (pps: v1.4) -->
	<xsl:template match="tpi:BloodPressures">
		<xsl:element name="BloodPressures" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:for-each select="./tpi:BloodPressure">
				<xsl:sort select="./tpi:RecordedDate" data-type="text" order="descending"/>
				<xsl:sort select="./tpi:RecordedTime" data-type="text" order="descending"/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
	<!-- Sort by date and time and map BODY_MEASUREMENTS_TYPE (tpi: v1.7) to BODY_MEASUREMENTS_TYPE (pps: v1.4) -->
	<xsl:template match="tpi:BodyMeasurements">
		<xsl:element name="BodyMeasurements" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:for-each select="./tpi:BodyMeasurement">
				<xsl:sort select="./tpi:RecordedDate" data-type="text" order="descending"/>
				<xsl:sort select="./tpi:RecordedTime" data-type="text" order="descending"/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
	<!-- Sort by date and time and map PREGNANCY_HISTORY_TYPE (tpi: v1.7) to PREGNANCY_HISTORY_TYPE (pps: v1.4) -->
	<xsl:template match="tpi:PregnancyHistory">
		<xsl:element name="PregnancyHistory" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:for-each select="./tpi:Pregnancies">
				<xsl:sort select="./tpi:RecordedDate" data-type="text" order="descending"/>
				<xsl:sort select="./tpi:RecordedTime" data-type="text" order="descending"/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
	<xsl:template match="tpi:ReferralToTreatmentData">
	<!-- Pull the UCPN out of the referral to treatment data and put it in the Document Data -->
		<xsl:if test="normalize-space(tpi:UniqueCarePathwayNumber)!=''">
			<xsl:element name="DocumentData" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:element name="UniqueCarePathwayNumber" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
					<xsl:value-of select="tpi:UniqueCarePathwayNumber"/>
				</xsl:element>
			</xsl:element>
		</xsl:if>
		
		<!-- Now copy all the other RTT data across -->
		<xsl:element name="ReferralToTreatmentData" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:apply-templates select="tpi:RTTStatus" />
			<xsl:apply-templates select="tpi:DateOfOriginalReferral"/>
			<xsl:apply-templates select="tpi:DaysElapsed"/>
			<xsl:element name="PeriodsOfFutureUnavailability" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
				<xsl:apply-templates select="tpi:PeriodsOfFutureUnavailability"/>
			</xsl:element>
			<xsl:apply-templates select="tpi:AdditionalInformation" />
<!--
			<xsl:for-each select="./*">
				<xsl:if test="name()!='UniqueCarePathwayNumber'">
					<xsl:element name="{local-name()}" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
						<xsl:apply-templates select="node()|@*"/>
					</xsl:element>
				</xsl:if>
			</xsl:for-each>
-->
		</xsl:element>
	</xsl:template>
	<xsl:template match="tpi:PeriodsOfFutureUnavailability">
		<xsl:element name="PeriodOfFutureUnavailability" namespace="http://www.show.scot.nhs.uk/isd/PrePopulationSource">
			<xsl:apply-templates select="./*" /> 
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>
