// ============================================================================================
// File name:       date.js
// Created:         27-Apr-2004
// Author:          S. Craig (RTEL)
// Description:     This file contains date validation functions.
// Dependencies:
// Issues:
// ============================================================================================

var     g_strMonthArray = new Array("Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec");

// ============================================================================================
function validateDate(objElement)
// Description:  Wrapped function used to call the date validation functionality within the
//               protocol screens.  Updates the supplied form element with date with default
//               format when valid.
// Pass:         HTML form element.
// Return:       Boolean value indicating whether the 
// Raise Errors: None
// -----------------------------------------------------
// Date          Developer                  Comments
// 04-May-2004   S.Craig (RTEL)             Created
// ============================================================================================
{
    var strDate;
    var blnValid = true;
    
    // If an object is supplied and the value isn't empty
    if ((objElement!=null) & (objElement.value.length != 0))
    {
        // If the supplied date has a valid format
        if ( (strDate=validateDateText(objElement.value)) != "")
            // Copy the newly formatted date back to the HTML form
            objElement.value    = strDate;
        else
            // The date is invalid
            blnValid            = false;
    }

    return blnValid;
}


// ============================================================================================
function validateDateText(strFullDate)
// Description:  Validates the date value stored in the supplied text object.
// Pass:         Date as a text string.
// Return:       Reformatted date as a text string if valid, empty otherwise.
// Raise Errors: None
// -----------------------------------------------------
// Date          Developer                  Comments
// 27-Apr-2004   S.Craig (RTEL)             Created
// 04-May-2004   S.Craig (RTEL)             Was validateDate.  Changed function to take a 
//                                          date string and return a date string, to make the
//                                          function more re-usable.
// ============================================================================================
{
    var     strDate;
    var     strMonth;
    var     strYear;
    var     intMonth;
    var     chrDelimiter;
    var     strDateArray;
    var     blnValid        = false;
    
    // Remove leading and trailing spaces.    
    strFullDate = TrimString(strFullDate);
    
    // Check the supplied date for delimiter characters
    chrDelimiter=checkDelimiter(strFullDate);

    // If a valid set of delimiters were found
    if (chrDelimiter != '')
    {
        // Split the supplied date into its constituent components
        strDateArray = strFullDate.split(chrDelimiter);
        
        // If date string splits into the correct number of fields
        if (strDateArray.length == 3)
        {
            //  Obtain the date, month and year components
            strDate  = strDateArray[0];
            strMonth = strDateArray[1];
            strYear  = strDateArray[2];

            // If the year had a valid length
            if (strYear.length == 4)
            {
                // Convert the month to a numeric value
                // The Date object uses 0 to 11 to denote month
                // therefore it is necessary to subtract one
                // from the supplied numeric value.
                switch (strMonth.length)
                {
                    case    1:
                    case    2: 
                        intMonth = strMonth-1; 
                        break;
                    case    3: 
                        intMonth = getNumericalMonth(strMonth)-1;
                        break;
                    default:
                        intMonth = -1;
                }

                try
                {
                    // Create a date object using the parsed values, i.e
                    // -    set the Year;
                    // -    set the Month;
                    // -    set the Date.
                    objDate = new Date(strYear, intMonth, strDate);

                    // Set the flag indicating that the supplied date
                    // is valid when the get methods of the date object
                    // return exactly the same values as passed in.
                    blnValid = (    (strDate  == objDate.getDate()    )   && 
                                    (intMonth == objDate.getMonth()   )   && 
                                    (strYear  == objDate.getFullYear())    );
                }
                catch (e)
                {
                    // Do nothing.  We assume that the exception was
                    // thrown because the supplied date is invalid
                }
            }
        }
    }
    
    // If the date was found to have a valid format, then replace the 
    // entered value with the default format.
    if (blnValid)
        strFullDate = formatDateToDefault(objDate);
    else
        strFullDate = "";

    return strFullDate;
}


// ============================================================================================
function checkDelimiter(strDate)
// Description:  Checks for one of three types of delimiter in the supplied date value.
//               If none, or more than one type is found, then it returns an empty delimiter.
// Pass:         String containing date.
// Return:       Delimiter character.
// Raise Errors: None
// -----------------------------------------------------
// Date          Developer                  Comments
// 27-Apr-2004   S.Craig (RTEL)             Created
// ============================================================================================
{
    var blnFound            = false;
    var chrDelimiter        = '';
    var chrDelimiterArray   = new Array('.', '/', '-');

    // Set the current delimiter to empty
    chrDelimiter = '';

    for (var intCnt=0 ; intCnt < chrDelimiterArray.length ; intCnt++)
    {
        // If the current delimiter character appears in the specified
        // date string
        if (strDate.indexOf(chrDelimiterArray[intCnt]) >= 0)
        {
            // If the delimiter isn't currently set
            if (!blnFound)
            {
                // Store the delimiter information and set the validity
                // flag to indicate that we have detected a valid delimiter.
                chrDelimiter    = chrDelimiterArray[intCnt];
                blnFound        = true;
            }
            else
            {
                // Otherwise set the delimiter flag to indicate that we
                // have detected an additional, conflicting delimiter in
                // the date text.
                chrDelimiter    = '';
            }
        }
    }
    
    return chrDelimiter;
}


// ============================================================================================
function getNumericalMonth(strMonth)
// Description:  Determines the numerical equaivalent associated with a month name abbreviation
//               i.e. Jan = 1, Feb = 2, etc., Nov = 11, Dec = 12
// Pass:         String representation of month name,
// Return:       Month number.
// Raise Errors: None
// -----------------------------------------------------
// Date          Developer                  Comments
// 27-Apr-2004   S.Craig (RTEL)             Created
// ============================================================================================
{
    var     intMonth    = -1;
    
    for (var intCnt=0 ; (intCnt<g_strMonthArray.length) && (intMonth==-1) ; intCnt++)
        if (strMonth.toUpperCase() == g_strMonthArray[intCnt].toUpperCase())
           intMonth = intCnt+1;
    
    return intMonth;
}


// ============================================================================================
function formatDateToDefault(objDate)
// Description:  Formats the date contained within the specified date object to a standard
//               default format.
// Pass:         Date object
// Return:       String representation of date.
// Raise Errors: None
// -----------------------------------------------------
// Date          Developer                  Comments
// 27-Apr-2004   S.Craig (RTEL)             Created
// ============================================================================================
{
    var strDate;

    strDate = (objDate.getDate() < 10 ? "0" : "") + objDate.getDate() + "-" + g_strMonthArray[objDate.getMonth()] + "-" + objDate.getFullYear();
    return strDate;
}


// ============================================================================================
function TrimString(sInString) {
// Description:  Removes leading and trailing whitespace from the String object.
// Pass:         String object.
// Return:       String object minus leading and trailing spaces.
// Raise Errors: None
// -----------------------------------------------------
// Date          Developer                  Comments
// 27-Apr-2004   S.Craig (RTEL)             Created
// ============================================================================================
  sInString = sInString.replace( /^\s+/g, "" );// strip leading
  return sInString.replace( /\s+$/g, "" );// strip trailing
}
