﻿/*
** InteractiveForms.js
**
** Script file of routines for interactivity within the viewmessage web form such as hiding/showing questions based on the values
** in other questions. This file also contains validation functions for protocol specified validations.
**
*/

IAForms = (function () {

    /* ==============================================================================================================================
    **          Constants (in UPPERCASE)
    ** ============================================================================================================================== */

    var TEXTINPUT = "textInput", TEXTAREAINPUT = "textAreaInput", DATEINPUT = "dateInput", CHECKBOXINPUT = "checkBoxInput",
        DROPDOWNINPUT = "dropDownInput", RADIOBUTTONINPUT = "radioButtonInput", DATATABLEINPUT = "dataTableInput",
        TABCONTENT = "tab",
    /* ==============================================================================================================================
    **          Private properties
    ** ============================================================================================================================== */

        targets = (function () {
            var targetstate = [],

            targetConstructor = function Target(id) {
                if (!(this instanceof Target)) {
                    return new Target();
                }

                this.Id = id;
                this.Type = "";
                this.allowSetVisibility = true;
                this.allowSetDisplay = true;
                this.allowSetRequired = true;
                this.allowSetValue = true;
                this.allowSetEnabled = true;
                this.targetState = ["visible", "displayed", "enabled", "optional"];
                return this;
            },

            addTarget = function () {
                var tType, tId = this.getAttribute("id"),
                    tobj = new Target(this.getAttribute("id")),
                    divQC = "#divQC_" + tId,
                    classes,
                    idx, maxIdx,
                    setState = function (target, classes) {
                        if (classes != null) {
                            classes = classes.split(' ');

                            for (maxIdx = classes.length, idx = 0; idx < maxIdx; idx += 1) {
                                switch (classes[idx]) {
                                    case "visible":
                                        break;
                                    case "invisible":
                                    case "invisiblePost":
                                        target.targetState[0] = classes[idx];
                                        //_setVisibility(target, classes[idx]);
                                        break;
                                    case "displayed":
                                        break;
                                    case "hidden":
                                    case "hiddenPost":
                                        target.targetState[1] = classes[idx];
                                        //_setDisplay(target, classes[idx]);
                                        break;
                                    case "enabled":
                                        break;
                                    case "disabled":
                                    case "disabledPost":
                                        _setEnabled(target, classes[idx]);
                                        break;
                                    case "required":
                                        target.targetState[3] = classes[idx];
                                        break;
                                    case "optional":
                                        break;
                                    case "questionInput":
                                        break;
                                    default:
                                        // Not an interesting class so ignore.
                                }
                            }
                        }
                    };

                //alert("Initialising targets: " + this.getAttribute("id") + ", " + this.getAttribute("type") + ", " + this.tagName);
                switch (this.tagName) {
                    case "INPUT":
                        switch (this.getAttribute("type")) {
                            case "text":
                                tobj.Type = TEXTINPUT;
                                break;
                            case "checkbox":
                                tobj.Type = CHECKBOXINPUT;
                            case "hidden":
                                break;
                            case "radio":
                                tobj.Type = RADIOBUTTONINPUT;
                                tobj.Id = tId = tId.substring(0, tId.lastIndexOf("_"));
                                break;
                        }

                        if ((tType == TEXTINPUT) && (this.className.indexOf("dateInput", 0) >= 0)) {
                            tobj.Type = DATEINPUT;
                        }
                        break;
                    case "TEXTAREA":
                        tobj.Type = TEXTAREAINPUT;
                        break;
                    case "SELECT":
                        tobj.Type = DROPDOWNINPUT;
                        break;
                    case "TABLE":
                        tobj.Type = DATATABLEINPUT;
                        tobj.allowSetRequired = false;
                        tobj.allowSetValue = false;
                        tobj.allowSetEnabled = false;
                        break;
                    case "DIV":
                        if (this.className.indexOf("categoryContent") >= 0) {
                            tobj.Type = TABCONTENT;
                            tobj.Id = this.getAttribute("name");
                            tobj.allowSetRequired = false;
                            tobj.allowSetVisibility = false;
                            tobj.allowSetDisplay = false;
                            tobj.allowSetValue = false;
                            tobj.allowSetEnabled = false;
                        }
                        break;
                    case "P":
                    case "B":
                    case "U":
                    case "I":
                    case "H1":
                    case "H2":
                    case "H3":
                    case "SPAN":
                        //alert("Found html tag with id : " + this.tagName + ", " + tId);
                        tobj.Type = this.tagName;
                        tobj.allowSetRequired = false;
                        tobj.allowSetEnabled = false;
                        tobj.allowSetValue = false;
                        break;
                    default:
                        alert("Unknown element encountered while iterating questions (" + this.tagName + ")");
                }

                // Set the state from the classes to ensure we have performed all required actions
                // such as using dsabled icons, etc. The state classes are split between to div that wraps
                // all question content and the input element itself
                classes = $(divQC).attr("class");
                setState(tobj, classes);
                classes = $("#" + tId).attr("class");
                setState(tobj, classes);
                classes = $("#" + tId + "_1.radioOption").attr("class");
                setState(tobj, classes);

                if (!_allowedTarget(tId)) {
                    tobj.allowSetRequired = tobj.allowSetDisplay = tobj.allowSetEnabled = tobj.allowSetValue = tobj.allowSetVisibility = false;
                }

                // Radio buttons have 1 input per option, but we only want to add the question id
                // once per question not once per option
                if ((tobj.Type != RADIOBUTTONINPUT) || (this.getAttribute("id") == tId + "_1")) {
                    targetstate.push(tobj);
                }
            },

            getTargetType = function (targetID) {
                var idx, maxIdx;

                for (maxIdx = targetstate.length, idx = 0; idx < maxIdx; idx += 1) {
                    if (targetstate[idx].Id == targetID)
                        return targetstate[idx].Type;
                }

                return "";
            },

            getTarget = function (targetID) {
                var idx, maxIdx;

                for (maxIdx = targetstate.length, idx = 0; idx < maxIdx; idx += 1) {
                    if (targetstate[idx].Id == targetID)
                        return targetstate[idx];
                }

                alert("getTarget: Unknown target - " + targetID);
                return new Target(targetID);

            },

            buildStateInputs = function () {
                var inputs = "", postElement, postValue;

                for (maxIdx = targetstate.length, idx = 0; idx < maxIdx; idx += 1) {
                    postValue = targetstate[idx].targetState.toString();
                    if (targetstate[idx].isDisabled()) {
                        if (targetstate[idx].Type == RADIOBUTTONINPUT) {
                            postValue += "," + $("#divQC_" + targetstate[idx].Id + " input[checked]").attr("value");
                        }
                        else {
                            postValue += "," + $("#" + targetstate[idx].Id).val()
                        }
                    }
                    postElement = "<INPUT type='hidden' id='" + targetstate[idx].Id + "_iaf_state' name='" + targetstate[idx].Id + "_iaf_state' value='" + postValue + "'>";
                    inputs += postElement;
                }

                return inputs;
            };

            Target.prototype.storeState = function (state) {
                switch (state.toLowerCase()) {
                    case "visible":
                    case "invisible":
                    case "invisiblepost":
                        this.targetState[0] = state;
                        break;
                    case "displayed":
                    case "hidden":
                    case "hiddenpost":
                        this.targetState[1] = state;
                        break;
                    case "enabled":
                    case "disabled":
                    case "disabledpost":
                        this.targetState[2] = state;
                        break;
                    case "required":
                    case "optional":
                        this.targetState[3] = state;
                        break;
                    default:
                        alert("Unknown state passed to storeState : " + state);
                }
            };

            Target.prototype.isDisabled = function () {
                var is_disabled;

                switch (this.targetState[2]) {
                    case "enabled":
                        is_disabled = false;
                        break;
                    case "disabled":
                    case "disabledPost":
                        is_disabled = true;
                        break;
                    default:
                        is_disabled = null;
                }

                return is_disabled;
            };

            Target.prototype.isAccessible = function () {
                if (this.targetState[0] == "invisible" || this.targetState[1] == "hidden" || this.targetState[2] == "disabled") {
                    return false;
                }
                else {
                    return true;
                }
            };

            Target.prototype.isRequired = function () {
                if (this.targetState[3] == "required") {
                    return true;
                }
                else {
                    return false;
                }
            };

            Target.prototype.canGetFocus = function () {
                if (this.targetState[0] == "visible" && this.targetState[1] == "displayed" && this.targetState[2] == "enabled") {
                    return true;
                }
                else {
                    return false;
                }
            };

            return {
                addTarget: addTarget,
                getTarget: getTarget,
                targetType: getTargetType,
                buildStateInputs: buildStateInputs
            };
        } ()),


    /* ==============================================================================================================================
    **          Private methods
    ** ============================================================================================================================== */

    _initialise = function () {

        $(".questionInput, .radioOption, div.dynaTable table, div.categoryContent").each(targets.addTarget);
        $("p[id], b[id], u[id], i[id], span[id], h1[id], h2[id], h3[id]").each(targets.addTarget);

    },

    /*
    /*
    ** =============================================================================
    **
    **  allowedTarget(targetID)
    **
    **  Is the passed targetID allowed to be modified? Some targets/questions such as
    **  destination specialty, hospital, etc should not be modifiable by actions on
    **  forms.
    **
    ** targetID         is the id of the question / tab / whatever to check
    **
    ** returns:         true if targetID is allowed to be modified, false otherwise
    **
    **
    ** =============================================================================
    */
    _allowedTarget = function (targetID) {
        var idx,
            maxidx,
            lcTargetID = targetID.toLowerCase(),
            disallowedTargets = ["specialtyref", "specialty", "hospital_id", "hospital_name", "hospital_address",
            "protocol", "hcp_id", "hcp_forename", "hcp_surname", "hcp_fullname"];

        for (idx = 0, maxidx = disallowedTargets.length; idx < maxidx; idx += 1) {
            if (disallowedTargets[idx] == lcTargetID) {
                return false;
            }
        }

        return true;
    },

    /*
    ** =============================================================================
    **
    ** setVisibility(target, actionValue)
    **
    ** Set the visibility of the passed element.
    **
    ** target           is the target of the question / tab / whatever to set the visibility state on
    **
    ** actionValue      is the value to set and should be visible, invisible or invisiblePost
    **
    **
    ** =============================================================================
    */

    _setVisibility = function (target, actionValue) {
        var divTarget = '#divQC_' + target.Id;

        if (target.allowSetVisibility) { // Some targets cannot have their visibility changed
            switch (actionValue) {
                case "visible":
                    $(divTarget).removeClass("invisible invisiblePost");
                    $(divTarget).addClass("visible");
                    target.storeState(actionValue);
                    break;
                case "invisible":
                    $(divTarget).removeClass("visible invisiblePost");
                    $(divTarget).addClass("invisible");
                    target.storeState(actionValue);
                    break;
                case "invisiblePost":
                    $(divTarget).removeClass("visible invisible");
                    $(divTarget).addClass("invisiblePost");
                    target.storeState(actionValue);
                    break;
                default:
                    alert("Invalid actlon value, " + actionValue + " passed to setVisibity");
            }
        }
        else {
            alert("Invalid target passed to setVisbility : " + target.Id);
        }

        return;
    },

    /*
    ** =============================================================================
    **
    ** setDisplay (target, actionValue)
    **
    ** Set the display state of the passed element.
    **
    ** target           is the target for the question / tab / whatever to set the display
    **                  state on
    **
    ** actionValue      is the value to set and should be displayed, hidden or hiddenPost. 
    **                  displayed and hiddenPost both get included in the xml whilst hidden
    **                  targets (and their descendents) are not.
    **
    **
    ** =============================================================================
    */

    _setDisplay = function (target, actionValue) {
        var divTarget = '#divQC_' + target.Id;

        if (target.allowSetDisplay) {
            switch (actionValue) {
                case 'displayed':
                    $(divTarget).removeClass("hidden hiddenPost");
                    $(divTarget).addClass("displayed");
                    target.storeState(actionValue);
                    break;
                case 'hidden':
                    $(divTarget).removeClass("displayed hiddenPost");
                    $(divTarget).addClass("hidden");
                    target.storeState(actionValue);
                    break;
                case 'hiddenPost':
                    $(divTarget).removeClass("displayed hidden");
                    $(divTarget).addClass("hiddenPost");
                    target.storeState(actionValue);
                    break;
                default:
                    alert('Invalid action value, ' + actionValue + ' passed to setDisplay');
            }
        }
        else {
            alert('Attempt to setDisplay on inaccessible target ' + target.Id + '.');
        }
    },

    /*
    ** =============================================================================
    **
    ** setEnabled (target, actionValue)
    **
    ** Set the enabled state of the passed element.
    **
    ** target           is the target of the question / tab / whatever to set the enabled state on
    **
    ** actionValue      is the value to set and should be enabled, disabled or disabledPost. 
    **                  enabled and disabledPost both get included in the xml whilst disabled
    **                  targets are not.
    **
    **
    ** =============================================================================
    */

    _setEnabled = function (target, actionValue) {
        var divTarget = '#divQC_' + target.Id,
        spellCheckTarget = "#" + target.Id + "_spellCheck",
        helpIconTarget = "#" + target.Id + "_helpIcon",
        dateIconTarget = "#" + target.Id + "_dateIcon",
        inputTarget = "#" + target.Id + ", #divQC_" + target.Id + " input.radioOption",
        spellIconSrc = "../graphics/spell.gif",
        helpIconSrc = "../graphics/help.gif",
        dateIconSrc = "../graphics/date.gif",
        disSpellIconSrc = "../graphics/disSpell.gif",
        disHelpIconSrc = "../graphics/disHelp.gif",
        disDateIconSrc = "../graphics/disDate.gif",
        src = "src";

        if (target.allowSetEnabled) {
            switch (actionValue) {
                case "enabled":
                    $(divTarget).removeClass("disabled");
                    // Need to 'enable' spellCheck and Help Icons (if there)
                    $(spellCheckTarget).attr(src, spellIconSrc);
                    $(spellCheckTarget).addClass("hand");
                    $(helpIconTarget).attr(src, helpIconSrc);
                    $(helpIconTarget).addClass("hand");
                    $(dateIconTarget).attr(src, dateIconSrc);
                    $(dateIconTarget).removeClass("hand");
                    target.storeState(actionValue);
                    $(inputTarget).removeAttr("disabled");
                    break;
                case "disabled":
                case "disabledPost":
                    $(divTarget).addClass("disabled");
                    // Need to 'disable' spellCheck and Help Icons (if there)
                    $(spellCheckTarget).attr(src, disSpellIconSrc);
                    $(spellCheckTarget).removeClass("hand");
                    $(helpIconTarget).attr(src, disHelpIconSrc);
                    $(helpIconTarget).removeClass("hand");
                    $(dateIconTarget).attr(src, disDateIconSrc);
                    $(dateIconTarget).removeClass("hand");
                    $(inputTarget).attr("disabled", "");
                    target.storeState(actionValue);
                    break;
                default:
                    alert('Invalid action value, ' + actionValue + ' passed to setEnabled');
            }
        }
        else {
            alert('Attempt to setEnabled on inaccessible target ' + target.Id + '.');
        }
    },

    /*
    ** =============================================================================
    **
    ** setRequired (target, actionValue)
    **
    ** Set the required state of the passed element.
    **
    ** target           is the target of the question / tab / whatever to set the required state on
    **
    ** actionValue      is the value to set and should be required or optional. 
    **
    **
    ** =============================================================================
    */

    _setRequired = function (target, actionValue) {
        var inputTarget = "#" + target.Id + ", #divQC_" + target.Id + " input.radioOption",
        htmlContent,
        requiredContentId = "<B>*</B>";

        if (target.allowSetRequired) {
            switch (actionValue) {
                case "required":
                    target.storeState(actionValue);
                    $(inputTarget).addClass("required");
                    inputTarget = "#divQC_" + target.Id + " label";
                    htmlContent = $(inputTarget).html();
                    if (htmlContent != null && htmlContent.length > 7 && htmlContent.substring(htmlContent.length - 8, htmlContent.length) != requiredContentId) {
                        $(inputTarget).html(htmlContent + requiredContentId);
                    }
                    break;
                case "optional":
                    target.storeState(actionValue);
                    $(inputTarget).removeClass("required");
                    inputTarget = "#divQC_" + target.Id + " label";
                    htmlContent = $(inputTarget).html();
                    if (htmlContent != null && htmlContent.length > 7 && htmlContent.substring(htmlContent.length - 8, htmlContent.length) == requiredContentId) {
                        htmlContent = htmlContent.substring(0, htmlContent.length - 8);
                        $(inputTarget).html(htmlContent);
                    }
                    break;
                default:
                    alert("Invalid action value, " + actionValue + " passed to setRequired");
            }
        }
        else {
            alert("Attempt to setRequired on inaccessible target " + target.Id + ".");
        }
    },


    /*
    ** =============================================================================
    **
    ** setValue (target, actionValue)
    **
    ** Set the required state of the passed element.
    **
    ** target           is the target of the question / tab / whatever to set the vaue of
    **
    ** actionValue      is the value to set the target's value to 
    **
    **
    ** =============================================================================
    */

    _setValue = function (target, actionValue) {
        var inputTarget = '#' + target.Id,
        checked = "checked";

        if (target.allowSetValue) {
            switch (target.Type) {
                case RADIOBUTTONINPUT:
                    inputTarget = "[name='" + target.Id + "']";
                    $(inputTarget).removeAttr(checked);
                    inputTarget = inputTarget + "[value='" + actionValue + "']";
                    $(inputTarget).attr(checked, checked);
                    $(inputTarget).trigger("change");
                    break;
                case CHECKBOXINPUT:
                    if (actionValue == "") {
                        $(inputTarget).removeAttr(checked);
                    }
                    else {
                        $(inputTarget).attr(checked, checked);
                    }
                    $(inputTarget).trigger("change");
                    break;
                case TEXTINPUT:
                case TEXTAREAINPUT:
                case DATEINPUT:
                case DROPDOWNINPUT:
                    $(inputTarget).val(actionValue).trigger("change");
                    break;
                default:
                    alert("Attempt to set value on invalid target " + target.Id + ". Target Type : " + target.Type);
            }
        }
        else {
            alert('Attempt to setRequired on inaccessible target ' + target.Id + '.');
        }
    },


    /*
    ** =============================================================================
    **
    ** isAccessible (targetID)
    **
    ** Is the passed target accessible, i.e. visible and not disabled
    **
    ** targetID         is the id of the question / tab / whatever to check the accessibiity of
    **
    ** return:          true if the target is accessible, false otherwise
    **
    **
    ** =============================================================================
    */

    _isAccessible = function (targetID) {
        return targets.getTarget(targetID).isAccessible();
    },

    /*
    ** =============================================================================
    **
    ** isRequired (targetID)
    **
    ** Is the passed target required, i.e. mandatory
    **
    ** targetID         is the id of the question / tab / whatever to check the required state of
    **
    ** return:          true if the target is required, false otherwise
    **
    **
    ** =============================================================================
    */

    _isRequired = function (targetID) {
        var target = targets.getTarget(targetID);

        return target.isAccessible() && target.isRequired();
    },

    /*
    ** =============================================================================
    **
    ** canGetFocus (targetID)
    **
    ** Is the passed target able to get focus, i.e. visible, displayed and enabled
    **
    ** targetID         is the id of the question / tab / whatever to check
    **
    ** return:          true if the target can receive focus, false otherwise
    **
    **
    ** =============================================================================
    */

    _canGetFocus = function (targetID) {
        var target = targets.getTarget(targetID);

        return target.canGetFocus();
    },

    /*
    ** =============================================================================
    **
    ** buildStateInputs ()
    **
    **  Create <INPUT> elements to store the interactivity state of the form so that they can be used when creating 
    **  the resultant message xml or used when opening a parked message to reset the state back to that when parked
    **  (as opposed to that when form newly opened).
    **
    ** =============================================================================
    */
    _buildStateInputs = function () {
        return targets.buildStateInputs();
    },

    /*
    ** =============================================================================
    **
    ** testInputValue (comparison, testValue, valueToTest)
    **
    **  Compare the value (of an input element) and return true if the test passes and false otherwise. For example
    **  testInputValue("greaterThan", "12", 15) will return true as the value to be tested (15) is greaterThan the test value (12).
    **
    ** =============================================================================
    */
    _testInputValue = function (comparison, testValue, valueToTest) {

        switch (comparison) {
            case "greaterThan":
            case "lessThan":
            case "greaterThanOrEqualTo":
            case "lessThanOrEqualTo":
            case "equalTo":
            case "isNumeric":
                return _testInputValueStd(comparison, testValue, valueToTest);
                break;
            case "pattern":
            case "notPattern":
                return _testInputValueRegEx(comparison, testValue, valueToTest);
                break;
            case "isEmpty":
                return valueToTest.length == 0;
                break;
            case "pastDate":
            case "pastOrPresentDate":
            case "futureDate":
            case "presentOrFutureDate":
            case "before":
            case "onOrBefore":
            case "after":
            case "onOrAfter":
            case "olderThanYears":
            case "youngerThanYears":
            case "olderThanMonths":
            case "youngerThanMonths":
            case "olderThanWeeks":
            case "youngerThanWeeks":
            case "olderThanDays":
            case "youngerThanDays":
                return _testInputValueDate(comparison, testValue, valueToTest);
                break;
            default:
                alert("Unknown comparison passed to _testInputValue (" + comparison + ")");
                return false;
        }
    },

    /*
    ** =============================================================================
    **
    ** testInputValueStd (comparison, testValue, valueToTest)
    **
    **  Perform standard comparisons such as greaterThan, lessThan , equals, greaterThanOrEqualTo.
    **  For example
    **
    **  _testInputValueStd("greaterThan", "12", 15) will return true as the value to be tested (15) is greaterThan the test value (12).
    ** =============================================================================
    */
    _testInputValueStd = function (comparison, testValue, valueToTest) {
        var nTestValue = Number(testValue), nValueToTest = Number(valueToTest);

        switch (comparison) {
            case "greaterThan":
                if (isNaN(nTestValue) || isNaN(nValueToTest)) {
                    return valueToTest > testValue;
                }
                else {
                    return nValueToTest > nTestValue;
                }
                break;
            case "lessThan":
                if (isNaN(nTestValue) || isNaN(nValueToTest)) {
                    return valueToTest < testValue;
                }
                else {
                    return nValueToTest < nTestValue;
                }
                break;
            case "greaterThanOrEqualTo":
                if (isNaN(nTestValue) || isNaN(nValueToTest)) {
                    return valueToTest >= testValue;
                }
                else {
                    return nValueToTest >= nTestValue;
                }
                break;
            case "lessThanOrEqualTo":
                if (isNaN(nTestValue) || isNaN(nValueToTest)) {
                    return valueToTest <= testValue;
                }
                else {
                    return nValueToTest <= nTestValue;
                }
                break;
            case "equalTo":
                return valueToTest == testValue;
                break;
            case "isNumeric":
                return !isNaN(nValueToTest);
            default:
                alert("Unknown comparison passed to _testInputValueStd (" + comparison + ")");
                return null;
        }
    },

    /*
    ** =============================================================================
    **
    ** testInputValueRegEx (comparison, testValue, valueToTest)
    **
    **  Perform regular expression comparisons such as pattern or notPattern.
    **  For example
    **
    **  _testInputValueStd("pattern", "([0-9])3", "023") will return true as a match for the regular expression "([0-9])3" is found
    **  in the value to be tested "023".
    ** =============================================================================
    */
    _testInputValueRegEx = function (comparison, testValue, valueToTest) {
        var regEx = new RegExp(testValue),
            match = regEx.test(valueToTest);

        switch (comparison) {
            case "pattern":
                break;
            case "notPattern":
                match = !match;
                break;
            default:
                alert("Unknown comparison passed to _testInputValueRegEx (" + comparison + ")");
                break;
        }

        return match;
    },

    /*
    ** =============================================================================
    **
    ** testInputValueDate (comparison, testValue, valueToTest)
    **
    **  Perform date comparisons such as onOrBefore, after, youngerThanYears, olderThanMonths, etc.
    **  For example
    **
    **  _testInputValueDate("olderThanYears", "18", "01-01-1990") will return true as the date being tested 01-01-1990, 
    **  is more than 18 years in the past.
    ** =============================================================================
    */
    _testInputValueDate = function (comparison, testValue, valueToTest) {
        var dateValueToTest = new Date(validateDateText(valueToTest).replace("-", " ")),
            dateTestValue = new Date(testValue.substr(6, 4), testValue.substr(3, 2) - 1, testValue.substr(0, 2)),
            numberTestValue = new Number(testValue),
            greaterThan = false,
            now = new Date(),
            today = new Date(now.getFullYear(), now.getMonth(), now.getDate()),
            compareResult;

        if (dateValueToTest == NaN) {
            alert("Invalid test date passed : " + valueToTest);
            return false;
        }

        switch (comparison) {
            case "pastDate":
                dateTestValue = today;
                greaterThan = true;
                break;
            case "pastOrPresentDate":
                dateTestValue = today;
                dateTestValue.setHours(24);
                greaterThan = true;
                break;
            case "futureDate":
                dateTestValue = today;
                greaterThan = false;
                break;
            case "presentOrFutureDate":
                dateTestValue = today;
                dateTestValue.setHours(-24);
                greaterThan = false;
                break;
            case "after":
                break;
            case "before":
                greaterThan = true;
                break;
            case "onOrBefore":
                dateTestValue.setHours(24);
                greaterThan = true;
                break;
            case "onOrAfter":
                dateTestValue.setHours(-24);
                break;
            case "olderThanYears":
                dateTestValue = today;
                dateTestValue.setFullYear(dateTestValue.getFullYear() - numberTestValue);
                greaterThan = true;
                break;
            case "youngerThanYears":
                dateTestValue = today;
                dateTestValue.setFullYear(dateTestValue.getFullYear() - numberTestValue);
                break;
            case "olderThanMonths":
                dateTestValue = today;
                dateTestValue.setMonth(today.getMonth() - numberTestValue);
                greaterThan = true;
                break;
            case "youngerThanMonths":
                dateTestValue = today;
                dateTestValue.setMonth(today.getMonth() - numberTestValue);
                break;
            case "olderThanWeeks":
                dateTestValue = today;
                dateTestValue.setHours(0 - numberTestValue * 168);
                greaterThan = true;
                break;
            case "youngerThanWeeks":
                dateTestValue = today;
                dateTestValue.setHours(0 - numberTestValue * 168);
                break;
            case "olderThanDays":
                dateTestValue = today;
                dateTestValue.setHours(0 - numberTestValue * 24);
                greaterThan = true;
                break;
            case "youngerThanDays":
                dateTestValue = today;
                dateTestValue.setHours(0 - numberTestValue * 24);
                break;
            default:
                alert("Unknown comparison passed to _testInputValue (" + comparison + ")");
                return false;
        }

        if (greaterThan) {
            compareResult = dateTestValue > dateValueToTest;
        }
        else {
            compareResult = dateTestValue < dateValueToTest;
        }

        return compareResult;
    };


    /* ==============================================================================================================================
    **          Public API
    ** ============================================================================================================================== */
    return {
        setVisibility: function (targetID, actionValue) { var target = targets.getTarget(targetID); return _setVisibility(target, actionValue); },
        setDisplay: function (targetID, actionValue) { var target = targets.getTarget(targetID); return _setDisplay(target, actionValue); },
        setEnabled: function (targetID, actionValue) { var target = targets.getTarget(targetID); return _setEnabled(target, actionValue); },
        setRequired: function (targetID, actionValue) { var target = targets.getTarget(targetID); return _setRequired(target, actionValue); },
        setValue: function (targetID, actionValue) { var target = targets.getTarget(targetID); return _setValue(target, actionValue); },
        buildStateInputs: _buildStateInputs,
        isAccessible: _isAccessible,
        isRequired: _isRequired,
        canGetFocus: _canGetFocus,
        testInputValue: _testInputValue,

        // Initialise function needs to be called in $(document).ready so that it can read all the target types (types of question)
        // after the document has been loaded.
        initialise: _initialise
    };
} ());

