<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
	<xsl:template match="sciGatewayProtocol">
		<xsl:element name="gwInternalProtocol">
			<xsl:copy-of select="./@*"/>
			<xsl:attribute name="renderVersion">2</xsl:attribute>
			<xsl:apply-templates select="tab"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="tab">
		<xsl:element name="category">
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="text"><xsl:value-of select="@caption"/></xsl:attribute>
			<xsl:apply-templates select="./node()"/>
		</xsl:element>
	</xsl:template>
	<!-- Convert checkBoxInput elements to questions as so much is rooted on everything being a question -->
	<xsl:template match="checkBoxInput">
		<xsl:element name="question">
			<xsl:attribute name="renderVersion">2</xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="type">check</xsl:attribute>
			<xsl:attribute name="text"><xsl:value-of select="./caption"/></xsl:attribute>
			<xsl:if test="caption/@location='above'">
				<xsl:attribute name="textLocation">above</xsl:attribute>
			</xsl:if>
			<xsl:if test="@required='required'">
				<xsl:attribute name="mandatory">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@display">
				<xsl:attribute name="display"><xsl:value-of select="@display"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@visible">
				<xsl:attribute name="visible"><xsl:value-of select="@visible"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@enabled">
				<xsl:attribute name="enabled"><xsl:value-of select="@enabled"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopObject">
				<xsl:attribute name="object"><xsl:value-of select="@prePopObject"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopProperty">
				<xsl:attribute name="property"><xsl:value-of select="@prePopProperty"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@width">
				<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@maxLength">
				<xsl:attribute name="maxlength"><xsl:value-of select="@maxLength"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@spellCheck">
				<xsl:attribute name="spellCheck"><xsl:value-of select="@spellCheck"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="./helpText">
				<xsl:element name="help"><xsl:value-of select="./helpText"/></xsl:element>
			</xsl:if>
			<xsl:copy-of select="checkedActions"/>
			<xsl:copy-of select="clearedActions"/>
		</xsl:element>
	</xsl:template>
	<!-- Convert textInput elements to questions as so much is rooted on everything being a question -->
	<xsl:template match="textInput">
		<xsl:element name="question">
			<xsl:attribute name="renderVersion">2</xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="type">text</xsl:attribute>
			<xsl:attribute name="text"><xsl:value-of select="./caption"/></xsl:attribute>
			<xsl:if test="caption/@location='above'">
				<xsl:attribute name="textLocation">above</xsl:attribute>
			</xsl:if>
			<xsl:if test="@required='required'">
				<xsl:attribute name="mandatory">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@display">
				<xsl:attribute name="display"><xsl:value-of select="@display"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@visible">
				<xsl:attribute name="visible"><xsl:value-of select="@visible"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@enabled">
				<xsl:attribute name="enabled"><xsl:value-of select="@enabled"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopObject">
				<xsl:attribute name="object"><xsl:value-of select="@prePopObject"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopProperty">
				<xsl:attribute name="property"><xsl:value-of select="@prePopProperty"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@width">
				<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@height">
				<xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@maxLength">
				<xsl:attribute name="maxlength"><xsl:value-of select="@maxLength"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@spellCheck">
				<xsl:attribute name="spellCheck"><xsl:value-of select="@spellCheck"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@initialValue">
				<xsl:attribute name="initialValue"><xsl:value-of select="@initialValue"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="./helpText">
				<xsl:element name="help"><xsl:value-of select="./helpText"/></xsl:element>
			</xsl:if>
			<xsl:copy-of select="./validationRule"/>
			<xsl:copy-of select="./interActivityRule"/>
		</xsl:element>
	</xsl:template>
	<!-- Convert textAreaInput elements to questions as so much is rooted on everything being a question -->
	<xsl:template match="textAreaInput">
		<xsl:element name="question">
			<xsl:attribute name="renderVersion">2</xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="type">textArea</xsl:attribute>
			<xsl:attribute name="text"><xsl:value-of select="./caption"/></xsl:attribute>
			<xsl:if test="caption/@location='above'">
				<xsl:attribute name="textLocation">above</xsl:attribute>
			</xsl:if>
			<xsl:if test="@required='required'">
				<xsl:attribute name="mandatory">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@display">
				<xsl:attribute name="display"><xsl:value-of select="@display"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@visible">
				<xsl:attribute name="visible"><xsl:value-of select="@visible"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@enabled">
				<xsl:attribute name="enabled"><xsl:value-of select="@enabled"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopObject">
				<xsl:attribute name="object"><xsl:value-of select="@prePopObject"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopProperty">
				<xsl:attribute name="property"><xsl:value-of select="@prePopProperty"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@width">
				<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@height">
				<xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@maxLength">
				<xsl:attribute name="maxlength"><xsl:value-of select="@maxLength"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@spellCheck">
				<xsl:attribute name="spellCheck"><xsl:value-of select="@spellCheck"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@initialValue">
				<xsl:attribute name="initialValue"><xsl:value-of select="@initialValue"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="./helpText">
				<xsl:element name="help"><xsl:value-of select="./helpText"/></xsl:element>
			</xsl:if>
			<xsl:copy-of select="./validationRule"/>
			<xsl:copy-of select="./interActivityRule"/>
		</xsl:element>
	</xsl:template>
	<!-- Convert dateInput elements to questions as so much is rooted on everything being a question -->
	<xsl:template match="dateInput">
		<xsl:element name="question">
			<xsl:attribute name="renderVersion">2</xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="type">date</xsl:attribute>
			<xsl:attribute name="text"><xsl:value-of select="./caption"/></xsl:attribute>
			<xsl:if test="caption/@location='above'">
				<xsl:attribute name="textLocation">above</xsl:attribute>
			</xsl:if>
			<xsl:if test="@required='required'">
				<xsl:attribute name="mandatory">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@display">
				<xsl:attribute name="display"><xsl:value-of select="@display"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@visible">
				<xsl:attribute name="visible"><xsl:value-of select="@visible"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@enabled">
				<xsl:attribute name="enabled"><xsl:value-of select="@enabled"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopObject">
				<xsl:attribute name="object"><xsl:value-of select="@prePopObject"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopProperty">
				<xsl:attribute name="property"><xsl:value-of select="@prePopProperty"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@width">
				<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@height">
				<xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@maxLength">
				<xsl:attribute name="maxlength"><xsl:value-of select="@maxLength"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@spellCheck">
				<xsl:attribute name="spellCheck"><xsl:value-of select="@spellCheck"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="./helpText">
				<xsl:element name="help"><xsl:value-of select="./helpText"/></xsl:element>
			</xsl:if>
			<xsl:copy-of select="./validationRule"/>
			<xsl:copy-of select="./interActivityRule"/>
		</xsl:element>
	</xsl:template>
	<!-- Convert dropDown elements to questions as so much is rooted on everything being a question -->
	<xsl:template match="dropDownInput">
		<xsl:element name="question">
			<xsl:attribute name="renderVersion">2</xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="type">select</xsl:attribute>
			<xsl:attribute name="text"><xsl:value-of select="./caption"/></xsl:attribute>
			<xsl:if test="caption/@location='above'">
				<xsl:attribute name="textLocation">above</xsl:attribute>
			</xsl:if>
			<xsl:if test="@required='required'">
				<xsl:attribute name="mandatory">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@display">
				<xsl:attribute name="display"><xsl:value-of select="@display"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@visible">
				<xsl:attribute name="visible"><xsl:value-of select="@visible"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@enabled">
				<xsl:attribute name="enabled"><xsl:value-of select="@enabled"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopObject">
				<xsl:attribute name="object"><xsl:value-of select="@prePopObject"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopProperty">
				<xsl:attribute name="property"><xsl:value-of select="@prePopProperty"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@width">
				<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@height">
				<xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@maxLength">
				<xsl:attribute name="maxlength"><xsl:value-of select="@maxLength"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="./helpText">
				<xsl:element name="help"><xsl:value-of select="./helpText"/></xsl:element>
			</xsl:if>
			<xsl:apply-templates select="option"/>
		</xsl:element>
	</xsl:template>
	<!-- Convert radioButtonInput elements to questions as so much is rooted on everything being a question -->
	<xsl:template match="radioButtonInput">
		<xsl:element name="question">
			<xsl:attribute name="renderVersion">2</xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="type">radio</xsl:attribute>
			<xsl:attribute name="text"><xsl:value-of select="./caption"/></xsl:attribute>
			<xsl:if test="caption/@location='above'">
				<xsl:attribute name="textLocation">above</xsl:attribute>
			</xsl:if>
			<xsl:if test="@required='required'">
				<xsl:attribute name="mandatory">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@display">
				<xsl:attribute name="display"><xsl:value-of select="@display"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@visible">
				<xsl:attribute name="visible"><xsl:value-of select="@visible"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@enabled">
				<xsl:attribute name="enabled"><xsl:value-of select="@enabled"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopObject">
				<xsl:attribute name="object"><xsl:value-of select="@prePopObject"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopProperty">
				<xsl:attribute name="property"><xsl:value-of select="@prePopProperty"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@width">
				<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@height">
				<xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@maxLength">
				<xsl:attribute name="maxlength"><xsl:value-of select="@maxLength"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@alignment">
				<xsl:attribute name="alignment"><xsl:value-of select="@alignment"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="./helpText">
				<xsl:element name="help"><xsl:value-of select="./helpText"/></xsl:element>
			</xsl:if>
			<xsl:apply-templates select="option"/>
		</xsl:element>
	</xsl:template>
	<!-- Convert dataTableInput elements to questions as so much is rooted on everything being a question -->
	<xsl:template match="dataTableInput">
		<xsl:element name="question">
			<xsl:attribute name="renderVersion">2</xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:attribute name="type"><xsl:call-template name="dynaTableTypeFromId"><xsl:with-param name="id" select="@id"/></xsl:call-template></xsl:attribute>
			<xsl:attribute name="text"><xsl:value-of select="./caption"/></xsl:attribute>
			<xsl:if test="caption/@location='above'">
				<xsl:attribute name="textLocation">above</xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopObject">
				<xsl:attribute name="object"><xsl:value-of select="@prePopObject"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="./helpText">
				<xsl:element name="help"><xsl:value-of select="./helpText"/></xsl:element>
			</xsl:if>
			<xsl:apply-templates select="./*"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="dataTableInput/caption">
		<!-- Ignore the caption element it's handled by the dataTableInput template -->
	</xsl:template>
	<xsl:template name="dynaTableTypeFromId">
		<xsl:param name="id"/>
		<xsl:choose>
			<xsl:when test="starts-with($id, 'structadmin_') or starts-with($id, 'fpadmin_') or starts-with($id, 'protresponse_')">giDynaTable</xsl:when>
			<xsl:otherwise>dynaTable</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="option">
		<xsl:element name="option">
			<xsl:attribute name="text"><xsl:value-of select="@caption"/></xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
			<xsl:if test="@isDefault">
				<xsl:attribute name="isDefault"><xsl:value-of select="@isDefault"/></xsl:attribute>
			</xsl:if>
			<xsl:apply-templates select="filters"/>
			<xsl:copy-of select="interActivityActions"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="textColumn">
		<xsl:element name="column">
			<xsl:attribute name="type">text</xsl:attribute>
			<xsl:attribute name="text"><xsl:value-of select="@caption"/></xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:if test="@display='hiddenPost'">
				<xsl:attribute name="hidden">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@required='required'">
				<xsl:attribute name="mandatory">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopProperty">
				<xsl:attribute name="property"><xsl:value-of select="@prePopProperty"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@width">
				<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@height">
				<xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@height">
				<xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@spellCheck">
				<xsl:attribute name="spellCheck"><xsl:value-of select="@spellCheck"/></xsl:attribute>
			</xsl:if>
			<xsl:copy-of select="validationRule"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="textAreaColumn">
		<xsl:element name="column">
			<xsl:attribute name="type">textArea</xsl:attribute>
			<xsl:attribute name="text"><xsl:value-of select="@caption"/></xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:if test="@display='hiddenPost'">
				<xsl:attribute name="hidden">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@required='required'">
				<xsl:attribute name="mandatory">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopProperty">
				<xsl:attribute name="property"><xsl:value-of select="@prePopProperty"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@width">
				<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@height">
				<xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@spellCheck">
				<xsl:attribute name="spellCheck"><xsl:value-of select="@spellCheck"/></xsl:attribute>
			</xsl:if>
			<xsl:copy-of select="validationRule"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="dateColumn">
		<xsl:element name="column">
			<xsl:attribute name="type">date</xsl:attribute>
			<xsl:attribute name="text"><xsl:value-of select="@caption"/></xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:if test="@display='hiddenPost'">
				<xsl:attribute name="hidden">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@required='required'">
				<xsl:attribute name="mandatory">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopProperty">
				<xsl:attribute name="property"><xsl:value-of select="@prePopProperty"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@width">
				<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@height">
				<xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
			</xsl:if>
			<xsl:copy-of select="validationRule"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="dropDownColumn">
		<xsl:element name="column">
			<xsl:attribute name="type">select</xsl:attribute>
			<xsl:attribute name="text"><xsl:value-of select="@caption"/></xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:if test="@display='hiddenPost'">
				<xsl:attribute name="hidden">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@required='required'">
				<xsl:attribute name="mandatory">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopProperty">
				<xsl:attribute name="property"><xsl:value-of select="@prePopProperty"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@width">
				<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@height">
				<xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
			</xsl:if>
			<xsl:for-each select="option">
				<xsl:element name="option">
					<xsl:attribute name="text"><xsl:value-of select="@caption"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
					<xsl:if test="@isDefault='true'">
						<xsl:attribute name="isDefault">true</xsl:attribute>
					</xsl:if>
				</xsl:element>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
	<xsl:template match="radioButtonColumn">
		<xsl:element name="column">
			<xsl:attribute name="type">radio</xsl:attribute>
			<xsl:attribute name="text"><xsl:value-of select="@caption"/></xsl:attribute>
			<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			<xsl:if test="@display='hiddenPost'">
				<xsl:attribute name="hidden">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@required='required'">
				<xsl:attribute name="mandatory">true</xsl:attribute>
			</xsl:if>
			<xsl:if test="@prePopProperty">
				<xsl:attribute name="property"><xsl:value-of select="@prePopProperty"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@width">
				<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@height">
				<xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
			</xsl:if>
			<xsl:for-each select="option">
				<xsl:element name="option">
					<xsl:attribute name="text"><xsl:value-of select="@caption"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
					<xsl:if test="@isDefault='true'">
						<xsl:attribute name="isDefault">true</xsl:attribute>
					</xsl:if>
				</xsl:element>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
	<xsl:template match="filters">
		<xsl:element name="filters">
			<xsl:attribute name="type">Generic</xsl:attribute>
			<xsl:if test="@count">
				<xsl:attribute name="count"><xsl:value-of select="@count"/></xsl:attribute>
			</xsl:if>
			<xsl:apply-templates select="filterGroup"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="filterGroup">
		<xsl:element name="filtergroup">
			<xsl:copy-of select="./@*"/>
			<xsl:copy-of select="filter"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="referrerControl | registeredGpControl">
		<xsl:element name="control">
			<xsl:attribute name="renderVersion">2</xsl:attribute>
			<xsl:if test="name()='referrerControl'">
				<xsl:attribute name="name">referrer</xsl:attribute>
			</xsl:if>
			<xsl:if test="name()='registeredGpControl'">
				<xsl:attribute name="name">registrar</xsl:attribute>
			</xsl:if>
			<xsl:if test="@autoSelect">
				<xsl:attribute name="autoselect"><xsl:value-of select="@autoSelect"/></xsl:attribute>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	<xsl:template match="h1">
		<xsl:element name="h1">
			<xsl:if test="@id">
				<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			</xsl:if>
			<xsl:value-of select="."/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="h2">
		<xsl:element name="h2">
			<xsl:if test="@id">
				<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			</xsl:if>
			<xsl:value-of select="."/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="h3">
		<xsl:element name="h3">
			<xsl:if test="@id">
				<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			</xsl:if>
			<xsl:value-of select="."/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="displayText">
			<xsl:apply-templates select="*"/>
	</xsl:template>
	<xsl:template match="layoutTable">
		<xsl:element name="table">
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="row"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="layoutTable/row">
		<xsl:element name="tr">
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="column"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="row/column">
		<xsl:element name="td">
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="* | text()"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="layoutPanel">
		<xsl:element name="div">
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="*"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="p">
		<xsl:element name="p">
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="* | text()"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="b">
		<xsl:element name="b">
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="* | text()"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="i">
		<xsl:element name="i">
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="* | text()"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="u">
		<xsl:element name="u">
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="* | text()"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="span">
		<xsl:element name="span">
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="* | text()"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="ol">
		<xsl:element name="ol">
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="* | text()"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="ul">
		<xsl:element name="ul">
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="* | text()"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="li">
		<xsl:element name="li">
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="* | text()"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="externalLink">
		<xsl:element name="a">
			<xsl:attribute name="href"><xsl:value-of select="@href"/></xsl:attribute>
			<xsl:if test="@id">
				<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@targetWindow">
				<xsl:attribute name="target"><xsl:value-of select="@targetWindow"/></xsl:attribute>
			</xsl:if>
			<xsl:value-of select="."/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="internalLink">
		<xsl:element name="a">
			<xsl:attribute name="href">#</xsl:attribute>
			<xsl:if test="@id">
				<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
			</xsl:if>
			<xsl:attribute name="targetID"><xsl:value-of select="@targetID"/></xsl:attribute>
			<xsl:value-of select="."/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="text()">
		<xsl:copy-of select="."/>
	</xsl:template>
</xsl:stylesheet>
